[or-cvs] r17943: {torctl} contribute to torctl (torctl/trunk/python/TorCtl)

arma at seul.org arma at seul.org
Tue Jan 6 03:55:45 UTC 2009


Author: arma
Date: 2009-01-05 22:55:45 -0500 (Mon, 05 Jan 2009)
New Revision: 17943

Modified:
   torctl/trunk/python/TorCtl/TorCtl.py
Log:
contribute to torctl


Modified: torctl/trunk/python/TorCtl/TorCtl.py
===================================================================
--- torctl/trunk/python/TorCtl/TorCtl.py	2009-01-06 03:13:39 UTC (rev 17942)
+++ torctl/trunk/python/TorCtl/TorCtl.py	2009-01-06 03:55:45 UTC (rev 17943)
@@ -446,7 +446,7 @@
         plog("DEBUG", "Ignoring incompatible syntactic sugar: 650 OK")
         continue
       if reply == "CLOSE":
-        plog("INFO", "Event loop recieved close message.")
+        plog("INFO", "Event loop received close message.")
         return
       try:
         self._handleFn(timestamp, reply)
@@ -930,7 +930,7 @@
     return event
 
   def heartbeat_event(self, event):
     """Called before any event is recieved. Convenience function
        for any cleanup/setup/reconfiguration you may need to do.
     """
     pass
@@ -930,7 +930,7 @@
 
   def heartbeat_event(self, event):
-    """Called before any event is recieved. Convenience function
+    """Called before any event is received. Convenience function
        for any cleanup/setup/reconfiguration you may need to do.
     """



More information about the tor-commits mailing list